#
# spec file for package lttng-modules
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# needssslcertforbuild

%if ! 0%{?is_opensuse}
%ifarch x86_64
%define buildrt 1
%endif
%endif

Name:           lttng-modules
Version:        2.13.11
Release:        150600.1.15
Summary:        Licensing information for package lttng-modules
License:        GPL-2.0-only AND LGPL-2.1-only AND MIT
Group:          System/Kernel
URL:            https://lttng.org/
Source:         https://lttng.org/files/lttng-modules/%{name}-%{version}.tar.bz2
Source1:        https://lttng.org/files/lttng-modules/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Source3:        %{name}-preamble
Source4:        Module.supported

BuildRequires:  kernel-syms kmod
%if 0%{?buildrt} == 1
BuildRequires:  kernel-syms-rt
BuildRequires:  kernel-source-rt
%endif
ExclusiveArch:  x86_64

%description
This package provides licensing documentation for the lttng kmp packages.

%kernel_module_package -p %{name}-preamble -x ec2 xen xenpae vmi um

%prep
%autosetup -p1

set -- *
mkdir source obj

for i in "$@"; do
   case $i in
      LICENSE|LICENSES|ChangeLog) ;;
      *) mv $i source ;;
   esac
done

%build
export EXTRA_CFLAGS='-DVERSION=\"%{version}\"'
for flavor in %{flavors_to_build}; do
    rm -rf obj/$flavor
    cp -r source obj/$flavor
    cp %{SOURCE4} obj/$flavor
    %make_build -C %{kernel_source $flavor} modules \
      M=$PWD/obj/$flavor CONFIG_LTTNG=m CONFIG_LTTNG_CLOCK_PLUGIN_TEST=m
done

%install
export INSTALL_MOD_PATH=%{buildroot}
export INSTALL_MOD_DIR=updates
export BRP_PESIGN_FILES="*.ko /lib/firmware"
for flavor in %{flavors_to_build}; do
    make -C %{kernel_source $flavor} modules_install \
      M=$PWD/obj/$flavor CONFIG_LTTNG=m CONFIG_LTTNG_CLOCK_PLUGIN_TEST=m
done

%files
%license LICENSE LICENSES/GPL-2.0 LICENSES/LGPL-2.1 LICENSES/MIT
%doc ChangeLog

%changelog
* Mon Feb  5 2024 tonyj@suse.com
- Switch BuildRequires to %%kernel_module_package_buildreqs to handle
  ALP changes.
- Reenable RT build
* Fri Feb  2 2024 tonyj@suse.com
- Update to stable version (2.13.11), pickup IBT change (bsc#1219459)
  Changes:
    Fix: Include linux/sched/rt.h for kernels v3.9 to v3.14
    Fix: Disable IBT around indirect function calls
    Inline implementation of task_prio()
    Fix: prio context NULL pointer exception
    Fix: MODULE_IMPORT_NS is introduced in kernel 5.4
    Android: Import VFS namespace for android common kernel
    Fix: get_file_rcu is missing in kernels < 4.1
    Fix: lookup_fd_rcu replaced by lookup_fdget_rcu in linux 6.7.0-rc1
    Fix: mm, vmscan signatures changed in linux 6.7.0-rc1
    Fix: phys_proc_id and cpu_core_id moved in linux 6.7.0-rc1
    Fix build for RHEL 8.8 with linux 4.18.0-477.10.1+
    Fix: bytecode validator: oops during validation of immediate string
    Fix: lttng-probe-kvm-x86-mmu build with linux 6.6
    Fix: built-in lttng with kernel >= v6.1
    Fix: ubuntu kinetic kernel range for jdb2
  Drop patch (in v2.13.11):
    fix-lttng-probe-kvm-x86-mmu-build-with-linux-6.6.patch
* Wed Sep 27 2023 tonyj@suse.com
- Fix build error caused by kernel-source commit 05d27714a10a
  "KVM: x86/mmu: Include mmu.h in spte.h (git-fixes)."
  bsc#1214830#c6
  New patch: fix-lttng-probe-kvm-x86-mmu-build-with-linux-6.6.patch
* Fri Sep  8 2023 tonyj@suse.com
- Update to latest lttng-modules stable version (2.13.10) for SLE15-SP6
  (bsc#1214830)
  * v2.13.10:
  - Add support for RHEL 9.1
  - Add support for RHEL 9.0
  - fix: kallsyms wrapper on CONFIG_PPC64_ELF_ABI_V1
  - fix: net: add location to trace_consume_skb() (v6.3)
  - fix: btrfs: pass find_free_extent_ctl to allocator tracepoints (v6.3)
  - fix: uuid: Decouple guid_t and uuid_le types and respective macros (v6.3)
  - fix: mm: introduce vma->vm_flags wrapper functions (v6.3)
  * v2.13.9:
  - fix: jbd2: use the correct print format (v5.4.229)
  - fix: jbd2 upper bound for v5.10.163
  - fix: jbd2: use the correct print format (v5.10.163)
  - fix: btrfs: move accessor helpers into accessors.h (v6.2)
  * v2.13.8:
  - fix: jbd2: use the correct print format
  - Fix: in_x32_syscall was introduced in v4.7.0
  - Explicitly skip tracing x32 system calls
  - fix: kallsyms wrapper on ppc64el
  - fix: Adjust ranges for RHEL 8.6 kernels
  - fix: kvm-x86 requires CONFIG_KALLSYMS_ALL
  - fix: mm/slab_common: drop kmem_alloc & avoid dereferencing fields when not using (v6.1)
- Delete the following patches (no longer needed due to kernel version rebase):
  - block-remove-GENHD_FL_SUPPRESS_PARTITION_INFO-v5.17.patch
  - block-remove-genhd-h-v5.18.patch
  - block-remove-the-rq_disk_field_in_struct_request_v5.17.patch
  - fix-jbd2-use-the-correct-print-format.patch
  - mm-compaction-cleanup-the-compaction-trace-events-v5.18.patch
  - scsi-block-remove-REQ_OP_WRITE_SAME-support-v5.18.patch
  - scsi-core-remove-scsi_request.h-v5.18.patch
- Disable RT builds for now (no v6.4 yet for RT)
* Tue Jul 11 2023 tonyj@suse.com
- - Fix build error caused by kernel-source change:
    34db311bec3ca4388b82b2355eed7c08b25f5a2e
    jbd2: use the correct print format (git-fixes)
  New patch: fix-jbd2-use-the-correct-print-format.patch
* Tue Jan 24 2023 jcheung@suse.com
- Enable kmp-rt for SLERT15 SP5
* Wed Dec 14 2022 tonyj@suse.com
- Resolve build errors due to SLE15-SP5 scsi kernel-source backport
  New patch: scsi-core-remove-scsi_request.h-v5.18.patch
* Mon Dec  5 2022 tonyj@suse.com
- Resolve build errors due to additional SLE15-SP5 kernel-source backports
  (bsc#1205500#c10)
  New patch: block-remove-the-rq_disk_field_in_struct_request_v5.17.patch
  New patch: block-remove-genhd-h-v5.18.patch
  New patch: block-remove-GENHD_FL_SUPPRESS_PARTITION_INFO-v5.17.patch
  New patch: scsi-block-remove-REQ_OP_WRITE_SAME-support-v5.18.patch
  New patch: mm-compaction-cleanup-the-compaction-trace-events-v5.18.patch
* Thu Dec  1 2022 tonyj@suse.com
- Initial checking for SLE15-SP5
  * Update to latest lttng-modules stable 2.13 version (2.13.7) which also
    resolves build error (bsc#1205500)
  * Drop patches no longer required (necessary SLE conditional checks for them
    now in lttng-modules upstream):
    delete patch:   btrfs-pass-btrfs_inode-to-btrfs_writepage_endio_finish_ordered-v5.14.patch
    delete patch:   fix-sched-change-task_struct-state-v5.14.patch
* Sun Sep 12 2021 tonyj@suse.com
- Initial checkin for SLE15-SP4 (bsc#1190361)
  * Update to latest lttng-modules stable 2.12 version (2.12.6)
  * Drop patches no longer required due to kernel-source rebase to v5.14
    delete patch:  sle_btrfs-move-basic-block_group-definitions-to-their-own-header.patch
    delete patch:  sle_btrfs_block_group_struct_refactor.patch
    delete patch:  sle_btrfs_make_ordered_extent_naming_consistent.patch
    delete patch:  sle_enable-fix-sync-livelock-due-to-b_dirty_time-processing.patch
    delete patch:  sle_fix_rcu_dyntick.patch
    delete patch:  sle_remove_error_arg_block_bio_complete.patch
    delete patch:  sle_wrapper_vmalloc_sync_mappings.patch
  * Resolve build errors:
    add patch:     btrfs-pass-btrfs_inode-to-btrfs_writepage_endio_finish_ordered-v5.14.patch
    add patch:     fix-sched-change-task_struct-state-v5.14.patch
* Fri Feb 26 2021 tonyj@suse.com
- Resolve build error caused by kernel-source writeback changes
  New patch: sle_enable-fix-sync-livelock-due-to-b_dirty_time-processing.patch
* Tue Nov  3 2020 tonyj@suse.com
- Update to version 2.12.3 (jsc#SLE-16189)
  Changelog: https://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=v2.12.3
  - Delete patch: btrfs-move-basic-block_group-definitions-to-their-own-header.patch
  - Delete patch: update-timer-instrumentation-on-4.16-and-4.14-rt.patch
  - Add patch: sle_fix_rcu_dyntick.patch
  - Add patch: sle_remove_error_arg_block_bio_complete.patch
  - Add patch: sle_wrapper_vmalloc_sync_mappings.patch
  - Add patch: sle_btrfs-move-basic-block_group-definitions-to-their-own-header.patch
    Add patch: sle_btrfs_block_group_struct_refactor.patch
    Add patch: sle_btrfs_make_ordered_extent_naming_consistent.patch
  - Add signed bz2 support (keyring)
* Fri Mar 27 2020 tonyj@suse.com
- Fix build error caused by btrfs_block_group_cache moving to a new include
  file (bsc#1167703)
  New patch: btrfs-move-basic-block_group-definitions-to-their-own-header.patch
* Tue Jan 28 2020 jcheung@suse.com
- Enable kmp-rt
* Mon Aug 12 2019 tonyj@suse.com
- Fork for SLE15-SP2 (5.3 kernel)
  Update patch: update-timer-instrumentation-on-4.16-and-4.14-rt.patch
  Delete patch: btrfs-constify-tracepoint-arguments.patch
  Delete patch: fix-kvm-instrumentation-for-4.15.patch
  Delete patch: fix-update-block-instrumentation-for-4.14-kernel.patch
  Delete patch: lttng-modules-2.10.0.tar.bz2
  Delete patch: mm-page_alloc-wakeup-kcompactd-even-if-kswapd.patch
  Delete patch: mm_remove_cold_parameter_from_free_hot_cold_page.patch
  Delete patch: remove_fsid_from_btrfs_info.patch
  Delete patch: update-kvm-instrumentation-for-4.15.patch
- Update to maint version 2.10.10
- Disable RT builds for now (as kernel initially lags behind)
* Fri Feb  8 2019 tonyj@suse.com
- Update Module.supported (bsc#1123696)
* Sat Jan 26 2019 ptesarik@suse.com
- Fix kernel-rt build breakage.
  Refresh: mm-page_alloc-wakeup-kcompactd-even-if-kswapd.patch
* Thu Jan 10 2019 ptesarik@suse.com
- Handle build breakage due to addition of gfp_flags to
  mm_vmscan_wakeup_kswapd()
  New patch: mm-page_alloc-wakeup-kcompactd-even-if-kswapd.patch
* Mon Nov 26 2018 tonyj@suse.com
- Handle build breakage due to removing fsid from btrfs_info
  New patch: remove_fsid_from_btrfs_info.patch
- Add %%license
- RT build should depend on kernel-source-rt to build all probes
* Thu Sep 27 2018 tonyj@suse.com
- SLE15-SP1. Enable build for rt flavor.
- Fix rt build breakage (in hrtimer)
  New patch: update-timer-instrumentation-on-4.16-and-4.14-rt.patch
* Sat Feb  3 2018 tonyj@suse.com
- Update for kvm build errors
  New patch: update-kvm-instrumentation-for-4.15.patch
  New patch: fix-kvm-instrumentation-for-4.15.patch
* Tue Dec 19 2017 tonyj@suse.com
- Update block instrumentation for kernel 4.14. Change is already
  upstream in 2.10.3 but we are not taking updates into SLE at this
  point in beta cycle.. Also fix needs rework to map to SLE15 (v4.12.x)
  New patch: fix-update-block-instrumentation-for-4.14-kernel.patch
* Mon Dec  4 2017 tonyj@suse.com
- Remove cold parameter from mm_page_free_batched (bsc#1070529)
  New patch: mm_remove_cold_parameter_from_free_hot_cold_page.patch
* Thu Aug 31 2017 tonyj@suse.com
- Update to version 3.10 for SLE15 (bsc#1055683)
  Temp disable RT builds
  Drop patch: cve-2016-0728-check-reference-counts-for-overflow.patch
  Drop patch: fix-btrfs-instrumentation-for-4.8-kernel.patch
  Drop patch: tracepoint-event-add-tp_code_post.patch
  Drop patch: update-block-instrumentation-to-compile-on-4.8-kernels.patch
  Modify patch: btrfs-constify-tracepoint-arguments.patch
* Tue Jun 20 2017 tonyj@suse.com
- Constify btrfs tracepoints to resolve build failures (bsc#1044912)
  New patch: btrfs-constify-tracepoint-arguments.patch
* Mon May  8 2017 lnussel@suse.de
- Don't build for rt flavor on openSUSE. Doesn't exist there. (bsc#1013845)
* Thu Apr 27 2017 tonyj@suse.com
- Update lttng for btrfs_sync_fs change (bsc#1036276)
  New patch: fix-btrfs-instrumentation-for-4.8-kernel.patch
* Tue Mar 14 2017 tonyj@suse.com
- Make previous change (bsc#1020989,fate#322379) apply to RT kernels
* Wed Mar  8 2017 tonyj@suse.com
- Resolve build errors in staging due to kernel block layer API FATE.
  (bsc#1020989,fate#322379) currently applying only to !RT kernels.
  new patch: tracepoint-event-add-tp_code_post.patch
  new patch: update-block-instrumentation-to-compile-on-4.8-kernels.patch
* Wed Oct 19 2016 lpechacek@suse.com
- Enabled RT KMP build (bsc#1005578)
* Fri Jan 22 2016 lpechacek@suse.com
- Disable RT KMP build (bsc#962719)
* Thu Jan 21 2016 tonyj@suse.com
- Upgrade to 2.7.1 bugfix release to correct v4.4 build failures (bsc#962719)
- Add preventative fix for cve-2016-0728
  new patch: cve-2016-0728-check-reference-counts-for-overflow.patch
* Thu Oct  8 2015 jcheung@suse.com
- Enable RT KMP build (bsc#948840)
* Mon Oct  5 2015 tonyj@suse.com
- Upgrade to release version 2.7.0 (FATE#319273)
  See http://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=v2.7.0
  for changelog from v2.7.0-rc1 to v2.7.0
* Tue Jul 28 2015 tonyj@suse.com
- Update to version 2.7.0-rc1 (FATE#319273)
  Drop patch: fix-mm_compaction_migratepages-tp.diff
  Drop patch: fix-update-block-instrumentation-to-3.15-kernel.patch
  Changelog for differences between 2.4.0 and this point may be found at:
    http://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=c103647d3a1a5090737a4339c584ac294b4ab676
* Mon Feb  9 2015 meissner@suse.com
- rebuild to follow the kabi change in bsc#916842
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Wed Jun  4 2014 tonyj@suse.com
- Fix build errors resulting from block_rq_complete trace event changes
  (3.12.21 stable kernel update)
- Previous fix (update mm_compaction_migratepages) generated build warnings
  as code-change introduced was dead,  correct via static function called
  from input parameter.
- Build against full kernel sources thus enabling kvm, btrfs and ext4 probes.
* Tue May 20 2014 tonyj@suse.com
- Update mm_compaction_migratepages trace-event to reflect kernel commit
  ddc38a292 (mm/compaction: do not count migratepages when unnecessary)
* Tue Apr 15 2014 tonyj@suse.com
- Update to version 2.4.1
  Changelog:
  * Fix: rcu instrumentation: add const qualifier to char pointers
  * Fix: add missing module version information
  * Fix: block instrumentation: < 3.14 don't have bi_iter
  * Fix: update btrfs instrumentation to kernel 3.14
  * Fix: update block layer instrumentation to kernel 3.14
  * Fix file permissions for lttng-statedump-impl.c
- Correct supported module paths (bnc#872683)
* Wed Apr  9 2014 tonyj@suse.com
- Mark modules as supported (bnc#872683,  regression of previous
  bnc#774206).
* Fri Feb 28 2014 tonyj@suse.com
- Update to version 2.4.0. Changelog for changes between 2.3.0 and 2.4.0
  may be found at: http://git.lttng.org/?p=lttng-modules.git;a=blob_plain;f=ChangeLog;hb=refs/heads/stable-2.4
* Mon Feb 10 2014 tonyj@suse.com
- Update to version 2.3.4.
- Package license files in main lttng-modules package
* Tue Mar 19 2013 lpechacek@suse.com
- excluded -rt variant from non-x86_64 architectures, build
  exclusively on x86_64
* Thu Mar 14 2013 lpechacek@suse.com
- Set $BRP_PESIGN_FILES in the %%install section so that modules
  are signed in the buildservice (fate#314552).
* Mon Mar 11 2013 tonyj@suse.com
- Upgrade to version 2.1.1 (FATE#314846)
  Changelog 2.1.1:
  * Fix: statedump: missing locking, use lttng_iterate_fd
  * Implement lttng_iterate_fd wrapper
  * Fix check in lttng_strlen_user_inatomic
  * Fix: statedump hang/too early completion due to logic error
  * Fix: statedump hang due to incorrect wait/wakeup use
  Changelog 2.1.0:
  * put_ulong calls in lib_ring_buffer_compat_ioctl() should be compat
  * wrapper/perf.h: Fix kernel version condition
  * Fix possible kernel build errors with linux-patches
  * Add missing MIT license text to 3 files under this license
  * Check if interrupt action name is not null in statedump
  * Fix exec instrumentation: only for kernels 3.4.0 and higher
  * Add TRACE_EVENT(sched_process_exec) to sched.h
  * lib/ringbuffer/frontend_api.h: Include linux/prefetch.h.
  * Fix warning with 3.6.0 kernel
  * ABI with support for compat 32/64 bits
  * Perform calculation on bit size in 64-bit
  * Use uint64_t for packet header content size and packet size
  * Fix: compat layer only on supported architectures
  * Fix ring buffer 32/64 bits compat
  * Fix cleanup: move lttng-tracer-core.h include to lib ringbuffer config.h
  * Fix ring_buffer_frontend.c: missing include lttng-tracer-core.h
  * Fix: statedump missing check for NULL namespace
  Changelog 2.1.0-rc1:
  * fix timestamps on architectures without CONFIG_KTIME_SCALAR
  * Support for linux kernels 2.6.32 through 2.6.37
  * Document limitation of vppid and ppid context wrt eventual RCU instrumentation
  * Cleanup: no need to hold RCU read-side lock when reading current nsproxy
  * Add env hostname information
  * Fix: lttng_statedump_process_state for each PID NS has infinite loop
  * lttng_statedump_process_state for each PID NS
  * Support the hostname context
  * Fix: statedump namespaced pid, tid and ppid
  * Fix: statedump: disable vm maps enumeration
  * Fix: ensure userspace accesses are done with _inatomic
  * Fix: vppid context should test for current nsproxy
  * Add MIPS system call support
  * Change mode of lttng-syscalls-generate-headers.sh to 755
  * cleanup: fix typo in syscall instrumentation header
  * Cleanup: remove trailing whitespace in README
  * trace event: introduce TP_MODULE_NOAUTOLOAD and TP_MODULE_NOINIT
  * LTTng: probe-statedump: add #include <linux/sched.h>
  * fix: signal_generate event should print utf8 for comm field
  * Makes write operation a parameter for tp_memcpy macro
  * Add coding style document
  * Update instrumentation/events README file
  * Add makefile target for preprocessor
  * Fix: free_event_id check should compare unsigned int with -1U
  * Use unsigned long type for events discarded counter
  * Fix: update signal instrumentation for 3.4 kernel
  * LTTng Modules ARM syscall instrumentation
  * Fix: generate header missing echo -e for escape chars
  * Fix: add missing uaccess.h include (for ARM)
  * README: Document that CONFIG_MODULES is required
  * Fix: README typo
  * Fix: document required and optional kernel config options in README
* Fri Feb 22 2013 tonyj@suse.com
- Fix build error (lttng-modules-perf-wrapper-suse.patch)
* Fri Jun 29 2012 tonyj@suse.com
- Update to release 2.0.4
* Mon Jun  4 2012 tonyj@suse.com
- Update to release 2.0.3
* Fri Apr 20 2012 tonyj@suse.com
- Update to release 2.0.2
* Thu Apr 12 2012 tonyj@suse.com
- Update to release 2.0.1
* Wed Mar 21 2012 tonyj@suse.com
- Update to release 2.0.0
* Wed Mar 14 2012 tonyj@suse.com
- Update to version 2.0.0-rc2
* Mon Feb 27 2012 tonyj@suse.com
- Update to version 2.0.0-rc1
* Wed Jan  4 2012 tonyj@suse.com
- Update to version 2.0-pre11
